# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
from abc import abstractproperty, ABC

class RoadmapItem(ABC):
    """
    Service Class


    See Also:
        `API RoadmapItem <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1RoadmapItem.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.RoadmapItem'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether a control is enabled or disabled.
        """
        ...

    @abstractproperty
    def ID(self) -> int:
        """
        The ID uniquely identifies the roadmap item.
        
        When the RoadmapItem is inserted into the Roadmap via \"insertByIndex\" the default value of the ID is the first available absolute digit that has not yet been assigned to other existing RoadmapItems.
        """
        ...

    @abstractproperty
    def Interactive(self) -> bool:
        """
        When \"Interactive\" is true the RoadmapItem supports a certain \"HyperLabelfunctionality\": Moving the mouse pointer over the RoadmapItem will change it to a Refhand and underline the Label for the time the mouse pointer resides over the RoadmapItem.
        
        Clicking with mouse pointer will then notify the Roadmap Container. The property Interactive\" is readonly because it is adapted from the container of the RoadmapItem.
        """
        ...

    @abstractproperty
    def Label(self) -> str:
        """
        The Label of the RoadmapItem does not include its Prefix that is automatically set after the following algorithm: (Index + 1) + \". \" + Label.
        """
        ...


__all__ = ['RoadmapItem']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from .x_text_content import XTextContent as XTextContent_b16e0ba5
    from .x_text_range import XTextRange as XTextRange_9a910ab7
    from .x_text_table import XTextTable as XTextTable_9a810ab2

class XTextConvert(XInterface_8f010a43):
    """
    allows converting selections of text to frames or tables.

    See Also:
        `API XTextConvert <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XTextConvert.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XTextConvert'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XTextConvert'

    @abstractmethod
    def convertToTable(self, TableRanges: typing.Tuple[object, ...], CellProperties: typing.Tuple[typing.Tuple[PropertyValues_d6470ce6, ...], ...], RowProperties: typing.Tuple[PropertyValues_d6470ce6, ...], TableProperties: PropertyValues_d6470ce6) -> XTextTable_9a810ab2:
        """
        converts the paragraphs marked in TableRanges into a table.
        
        The inner sequence contains the start and end paragraphs of each table cell. The next sequence groups the cells to a row and the outer sequence groups the rows of the table.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...
    @abstractmethod
    def convertToTextFrame(self, Start: XTextRange_9a910ab7, End: XTextRange_9a910ab7, FrameProperties: PropertyValues_d6470ce6) -> XTextContent_b16e0ba5:
        """
        moves the paragraphs from Start to End into a text frame.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
        """
        ...

__all__ = ['XTextConvert']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.inspection.default_help_provider import DefaultHelpProvider as DefaultHelpProvider
with suppress(ImportError):
    from ...dyn.inspection.generic_property_handler import GenericPropertyHandler as GenericPropertyHandler
with suppress(ImportError):
    from ...dyn.inspection.interactive_selection_result import InteractiveSelectionResult as InteractiveSelectionResult
with suppress(ImportError):
    from ...dyn.inspection.line_descriptor import LineDescriptor as LineDescriptor
with suppress(ImportError):
    from ...dyn.inspection.object_inspector import ObjectInspector as ObjectInspector
with suppress(ImportError):
    from ...dyn.inspection.object_inspector_model import ObjectInspectorModel as ObjectInspectorModel
with suppress(ImportError):
    from ...dyn.inspection.property_category_descriptor import PropertyCategoryDescriptor as PropertyCategoryDescriptor
with suppress(ImportError):
    from ...dyn.inspection.property_control_type import PropertyControlType as PropertyControlType
with suppress(ImportError):
    from ...dyn.inspection.property_control_type import PropertyControlTypeEnum as PropertyControlTypeEnum
with suppress(ImportError):
    from ...dyn.inspection.property_line_element import PropertyLineElement as PropertyLineElement
with suppress(ImportError):
    from ...dyn.inspection.property_line_element import PropertyLineElementEnum as PropertyLineElementEnum
with suppress(ImportError):
    from ...dyn.inspection.string_representation import StringRepresentation as StringRepresentation
with suppress(ImportError):
    from ...dyn.inspection.x_hyperlink_control import XHyperlinkControl as XHyperlinkControl
with suppress(ImportError):
    from ...dyn.inspection.x_numeric_control import XNumericControl as XNumericControl
with suppress(ImportError):
    from ...dyn.inspection.x_object_inspector import XObjectInspector as XObjectInspector
with suppress(ImportError):
    from ...dyn.inspection.x_object_inspector_model import XObjectInspectorModel as XObjectInspectorModel
with suppress(ImportError):
    from ...dyn.inspection.x_object_inspector_ui import XObjectInspectorUI as XObjectInspectorUI
with suppress(ImportError):
    from ...dyn.inspection.x_property_control import XPropertyControl as XPropertyControl
with suppress(ImportError):
    from ...dyn.inspection.x_property_control_context import XPropertyControlContext as XPropertyControlContext
with suppress(ImportError):
    from ...dyn.inspection.x_property_control_factory import XPropertyControlFactory as XPropertyControlFactory
with suppress(ImportError):
    from ...dyn.inspection.x_property_control_observer import XPropertyControlObserver as XPropertyControlObserver
with suppress(ImportError):
    from ...dyn.inspection.x_property_handler import XPropertyHandler as XPropertyHandler
with suppress(ImportError):
    from ...dyn.inspection.x_string_list_control import XStringListControl as XStringListControl
with suppress(ImportError):
    from ...dyn.inspection.x_string_representation import XStringRepresentation as XStringRepresentation



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class NumberFormat(metaclass=UnoConstMeta, type_name="com.sun.star.util.NumberFormat", name_space="com.sun.star.util"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.util.NumberFormat``"""
        pass

    class NumberFormatEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.util.NumberFormat", name_space="com.sun.star.util"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.util.NumberFormat`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.util import NumberFormat as NumberFormat
    else:
        # keep document generators happy
        from ...lo.util.number_format import NumberFormat as NumberFormat

    class NumberFormatEnum(IntEnum):
        """
        Enum of Const Class NumberFormat

        contains constants that are used to specify the type of a number format.
        """
        ALL = NumberFormat.ALL
        """
        selects all number formats.
        """
        DEFINED = NumberFormat.DEFINED
        """
        selects only user-defined number formats.
        """
        DATE = NumberFormat.DATE
        """
        selects date formats.
        """
        TIME = NumberFormat.TIME
        """
        selects time formats.
        """
        CURRENCY = NumberFormat.CURRENCY
        """
        selects currency formats.
        """
        NUMBER = NumberFormat.NUMBER
        """
        selects decimal number formats.
        """
        SCIENTIFIC = NumberFormat.SCIENTIFIC
        """
        selects scientific number formats.
        """
        FRACTION = NumberFormat.FRACTION
        """
        selects number formats for fractions.
        """
        PERCENT = NumberFormat.PERCENT
        """
        selects percentage number formats.
        """
        TEXT = NumberFormat.TEXT
        """
        selects text number formats.
        """
        DATETIME = NumberFormat.DATETIME
        """
        selects number formats which contain date and time.
        """
        LOGICAL = NumberFormat.LOGICAL
        """
        selects boolean number formats.
        """
        UNDEFINED = NumberFormat.UNDEFINED
        """
        is used as a return value if no format exists.
        """
        EMPTY = NumberFormat.EMPTY
        DURATION = NumberFormat.DURATION

__all__ = ['NumberFormat', 'NumberFormatEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.connection
from __future__ import annotations
import uno
from abc import abstractmethod
from .x_connection import XConnection as XConnection_f2320da0

class XConnection2(XConnection_f2320da0):
    """
    XConnection2 extends the XConnection interface with available and readSomeBytes

    See Also:
        `API XConnection2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1connection_1_1XConnection2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.connection'
    __ooo_full_ns__: str = 'com.sun.star.connection.XConnection2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.connection.XConnection2'

    @abstractmethod
    def available(self) -> int:
        """
        Gives the number of bytes available via read without blocking.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def readSomeBytes(self, aData: uno.ByteSequence, nMaxBytesToRead: int) -> int:
        """
        Blocks if no data is available otherwise reads at max nMaxBytesToRead but at least 1 byte.

        * ``aData`` is an out direction argument.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XConnection2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.container
from __future__ import annotations
from abc import abstractmethod, abstractproperty
from .x_element_access import XElementAccess as XElementAccess_cd60e3f

class XMap(XElementAccess_cd60e3f):
    """
    describes a map between keys and values.
    
    Keys in the map are unique, and each key maps to exactly one value.
    
    Locating elements in the map, both values and keys, requires a notion of equality of two objects. In conformance with the UNO type system, two values are said to be equal if and only if they have the same type, and both denote the same element of this type's value set.

    See Also:
        `API XMap <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1container_1_1XMap.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.container'
    __ooo_full_ns__: str = 'com.sun.star.container.XMap'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.container.XMap'

    @abstractmethod
    def clear(self) -> None:
        """
        clears the map, removing all key-value pairs from it.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def containsKey(self, Key: object) -> bool:
        """
        determines whether a mapping for he given key exists in the map

        Raises:
            com.sun.star.beans.IllegalTypeException: ``IllegalTypeException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def containsValue(self, Value: object) -> bool:
        """
        determines whether the map contains a mapping to a given value.

        Raises:
            com.sun.star.beans.IllegalTypeException: ``IllegalTypeException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def get(self, Key: object) -> object:
        """
        gets the value to which a given key maps.

        Raises:
            com.sun.star.beans.IllegalTypeException: ``IllegalTypeException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def put(self, Key: object, Value: object) -> object:
        """
        associates a given key with a given value
        
        If the map already contains a mapping for the given key, then the old value is replaced by the given new value.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
            com.sun.star.beans.IllegalTypeException: ``IllegalTypeException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def remove(self, Key: object) -> object:
        """
        removes a key-value mapping, given by key, from the map.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
            com.sun.star.beans.IllegalTypeException: ``IllegalTypeException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractproperty
    def KeyType(self) -> object:
        """
        denotes the type of the keys in the map.
        
        Implementations are free to accept any supertype of KeyType as keys.
        """
        ...

    @abstractproperty
    def ValueType(self) -> object:
        """
        denotes the type of the values in the map.
        
        Implementations are free to accept any supertype of the ValueType as values.
        """
        ...


__all__ = ['XMap']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XSupportedLocales(XInterface_8f010a43):
    """
    Offers information about which languages are supported by the object.
    
    This interface has to be implemented by com.sun.star.linguistic2.SpellChecker, com.sun.star.linguistic2.Hyphenator and com.sun.star.linguistic2.Thesaurus implementations in order to be queried for the languages they can use.

    See Also:
        `API XSupportedLocales <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XSupportedLocales.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XSupportedLocales'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XSupportedLocales'

    @abstractmethod
    def getLocales(self) -> typing.Tuple[Locale_70d308fa, ...]:
        """
        """
        ...
    @abstractmethod
    def hasLocale(self, aLocale: Locale_70d308fa) -> bool:
        """
        """
        ...

__all__ = ['XSupportedLocales']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.container
from __future__ import annotations
from abc import abstractmethod
from .x_implicit_id_replace import XImplicitIDReplace as XImplicitIDReplace_49260fa7

class XImplicitIDContainer(XImplicitIDReplace_49260fa7):
    """
    makes it possible to insert and remove elements in/from a container using an implicit (unique) ID.

    See Also:
        `API XImplicitIDContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1container_1_1XImplicitIDContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.container'
    __ooo_full_ns__: str = 'com.sun.star.container.XImplicitIDContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.container.XImplicitIDContainer'

    @abstractmethod
    def addWithImplicitID(self, aElement: object) -> str:
        """
        adds a new object to the container and generates an implicit (unique) ID for this object.
        """
        ...
    @abstractmethod
    def removeByImplicitID(self, ID: str) -> None:
        """
        removes an object from the container which is specified by an implicit (unique) identifier.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XImplicitIDContainer']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.uri
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_uri_reference import XUriReference as XUriReference_afc30b6f

class XUriSchemeParser(XInterface_8f010a43):
    """
    parses textual representations of absolute URIs.
    
    See RFC 3986 for a description of URIs and related terms.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUriSchemeParser <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uri_1_1XUriSchemeParser.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.uri'
    __ooo_full_ns__: str = 'com.sun.star.uri.XUriSchemeParser'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.uri.XUriSchemeParser'

    @abstractmethod
    def parse(self, scheme: str, schemeSpecificPart: str) -> XUriReference_afc30b6f:
        """
        parses the textual representation of an absolute URI.
        
        This method is used to parse URIs (with no fragment part), not URI references (with an optional fragment part).
        
        If an object is returned, the behaviour of its com.sun.star.uri.XUriReference methods must reflect the fact that the object represents an absolute URI reference with the given scheme and scheme-specific part, and without a fragment part.
        """
        ...

__all__ = ['XUriSchemeParser']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Defaulted(object):
    """
    Struct Class

    A value of a given type that can be defaulted.
    
    This structure is used as the type of interface attributes corresponding to instances of com.sun.star.beans.Property that have the com.sun.star.beans.PropertyAttribute.MAYBEDEFAULT.

    See Also:
        `API Defaulted <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1Defaulted_3_01T_01_4.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.Defaulted'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.beans.Defaulted'
    """Literal Constant ``com.sun.star.beans.Defaulted``"""

    def __init__(self, Value: typing.Optional[object] = None, IsDefaulted: typing.Optional[bool] = None) -> None:
        """
        Constructor

        Arguments:
            Value (object, optional): Value value.
            IsDefaulted (bool, optional): IsDefaulted value.
        """
        super().__init__()

        if isinstance(Value, Defaulted):
            oth: Defaulted = Value
            self.Value = oth.Value
            self.IsDefaulted = oth.IsDefaulted
            return

        kargs = {
            "Value": Value,
            "IsDefaulted": IsDefaulted,
        }
        if kargs["Value"] is UNO_NONE:
            kargs["Value"] = None
        if kargs["IsDefaulted"] is UNO_NONE:
            kargs["IsDefaulted"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._value = kwargs["Value"]
        self._is_defaulted = kwargs["IsDefaulted"]


    @property
    def Value(self) -> object:
        """
        The underlying value of this structure instance.
        
        Even if this structure instance is defaulted, this member should contain a useful value. If there is no useful value for a defaulted structure instance, com.sun.star.beans.Optional can be used as the type of this member.
        """
        return self._value

    @Value.setter
    def Value(self, value: object) -> None:
        self._value = value

    @property
    def IsDefaulted(self) -> bool:
        """
        Marks this structure instance as defaulted.
        """
        return self._is_defaulted

    @IsDefaulted.setter
    def IsDefaulted(self, value: bool) -> None:
        self._is_defaulted = value


__all__ = ['Defaulted']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XStringEscape(XInterface_8f010a43):
    """
    This interface is used to encode an arbitrary String into a escaped form.
    
    The escaped form is chosen to be suitable for use with other interfaces of the object or service providing this interface.
    
    Any characters or character sequences that are not compatible with any naming rules or restrictions must be replaced by an escaped form, that complies to these rules.
    
    The transformation should preserve all traits of the string that are generally respected by the service. For example, the case of a string may be lost after encoding and then decoding, if the service generally is case insensitive.
    
    Other than that the encoding is one-to-one and can be reversed. The encoding should try to preserve as much as possible of the original string, to keep human-readable input human-friendly where possible. Strings that already conform to the naming conventions should be left unchanged or minimally modified.

    See Also:
        `API XStringEscape <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XStringEscape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XStringEscape'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XStringEscape'

    @abstractmethod
    def escapeString(self, aString: str) -> str:
        """
        encodes an arbitrary string into an escaped form compatible with some naming rules.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def unescapeString(self, aEscapedString: str) -> str:
        """
        decodes an escaped string into the original form.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XStringEscape']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
from abc import abstractproperty
from .x_cell_range_referrer import XCellRangeReferrer as XCellRangeReferrer_91c0e23
from .x_named_range import XNamedRange as XNamedRange_af450b4b

class NamedRange(XCellRangeReferrer_91c0e23, XNamedRange_af450b4b):
    """
    Service Class

    represents a named range in a spreadsheet document.
    
    In fact a named range is a named formula expression. A cell range address is one possible content of a named range.
    
    **since**
    
        OOo 3.0

    See Also:
        `API NamedRange <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1NamedRange.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.NamedRange'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsSharedFormula(self) -> bool:
        """
        Determines if this defined name represents a shared formula.
        
        This special property shall not be used externally. It is used by import and export filters for compatibility with spreadsheet documents containing shared formulas. Shared formulas are shared by several cells to save memory and to decrease file size.
        
        A defined name with this property set will not appear in the user interface of Calc, and its name will not appear in cell formulas. A formula referring to this defined name will show the formula definition contained in the name instead.
        
        **since**
        
            OOo 3.0
        """
        ...

    @abstractproperty
    def TokenIndex(self) -> int:
        """
        returns the index used to refer to this name in token arrays.
        
        A token describing a defined name shall contain the op-code obtained from the FormulaMapGroupSpecialOffset.NAME offset and this index as data part.
        
        **since**
        
            OOo 3.0
        """
        ...


__all__ = ['NamedRange']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report.meta
from __future__ import annotations
import typing
from abc import abstractproperty
from ...beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ...lang.x_component import XComponent as XComponent_98dc0ab5
from ...sheet.x_formula_parser import XFormulaParser as XFormulaParser_d54d0cbc
if typing.TYPE_CHECKING:
    from ...sheet.formula_op_code_map_entry import FormulaOpCodeMapEntry as FormulaOpCodeMapEntry_37da0f61
    from ...sheet.x_formula_op_code_mapper import XFormulaOpCodeMapper as XFormulaOpCodeMapper_27ff0eee

class XFormulaParser(XPropertySet_bc180bfa, XComponent_98dc0ab5, XFormulaParser_d54d0cbc):
    """
    identifies a XFormulaParser which allows to retrieve the meta data of all supported functions.

    See Also:
        `API XFormulaParser <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1meta_1_1XFormulaParser.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report.meta'
    __ooo_full_ns__: str = 'com.sun.star.report.meta.XFormulaParser'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.meta.XFormulaParser'

    @abstractproperty
    def OpCodeMap(self) -> typing.Tuple[FormulaOpCodeMapEntry_37da0f61, ...]:
        """
        The complete mapping of Names to OpCodes.
        
        Names and symbols not defined here lead to a parser/print error.
        """
        ...

    @abstractproperty
    def FormulaOpCodeMapper(self) -> XFormulaOpCodeMapper_27ff0eee:
        """
        return the mapper for op codes.
        """
        ...


__all__ = ['XFormulaParser']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.lang
from __future__ import annotations
from .x_multi_component_factory import XMultiComponentFactory as XMultiComponentFactory_381b0f98
from .x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6

class MultiServiceFactory(XMultiComponentFactory_381b0f98, XMultiServiceFactory_191e0eb6):
    """
    Service Class

    Provides a collection of implementations of services.
    
    The factories for instantiating objects of implementations are accessed via a service name.
    
    The com.sun.star.container.XContentEnumerationAccess interface can be supported optionally. If it is supported, it is possible to enumerate all implementations that support the service specified with the argument of com.sun.star.container.XContentEnumerationAccess.createContentEnumeration(). The enumerator returns interfaces. The type of the interface is not specified. Commonly this is XSingleComponentFactory.

    See Also:
        `API MultiServiceFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1lang_1_1MultiServiceFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.MultiServiceFactory'
    __ooo_type_name__: str = 'service'


__all__ = ['MultiServiceFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .data_pilot_field_filter import DataPilotFieldFilter as DataPilotFieldFilter_271e0eed
from .data_result import DataResult as DataResult_a47d0b1a


class DataPilotTableResultData(object):
    """
    Struct Class

    information about a cell positioned within the result area of a DataPilot table.
    
    DataPilotTableResultData contains information about a particular cell positioned within the result area of a DataPilot table.
    
    **since**
    
        OOo 3.0

    See Also:
        `API DataPilotTableResultData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotTableResultData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotTableResultData'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.DataPilotTableResultData'
    """Literal Constant ``com.sun.star.sheet.DataPilotTableResultData``"""

    def __init__(self, FieldFilters: typing.Optional[typing.Tuple[DataPilotFieldFilter_271e0eed, ...]] = (), DataFieldIndex: typing.Optional[int] = 0, Result: typing.Optional[DataResult_a47d0b1a] = UNO_NONE) -> None:
        """
        Constructor

        Arguments:
            FieldFilters (typing.Tuple[DataPilotFieldFilter, ...], optional): FieldFilters value.
            DataFieldIndex (int, optional): DataFieldIndex value.
            Result (DataResult, optional): Result value.
        """
        super().__init__()

        if isinstance(FieldFilters, DataPilotTableResultData):
            oth: DataPilotTableResultData = FieldFilters
            self.FieldFilters = oth.FieldFilters
            self.DataFieldIndex = oth.DataFieldIndex
            self.Result = oth.Result
            return

        kargs = {
            "FieldFilters": FieldFilters,
            "DataFieldIndex": DataFieldIndex,
            "Result": Result,
        }
        if kargs["Result"] is UNO_NONE:
            kargs["Result"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._field_filters = kwargs["FieldFilters"]
        self._data_field_index = kwargs["DataFieldIndex"]
        self._result = kwargs["Result"]


    @property
    def FieldFilters(self) -> typing.Tuple[DataPilotFieldFilter_271e0eed, ...]:
        """
        This is a set of filter criteria that can be used to re-create those data rows that contribute to the value shown in the cell.
        """
        return self._field_filters

    @FieldFilters.setter
    def FieldFilters(self, value: typing.Tuple[DataPilotFieldFilter_271e0eed, ...]) -> None:
        self._field_filters = value

    @property
    def DataFieldIndex(self) -> int:
        """
        This is a 0-based index that specifies which data field the data displayed in the cell is for; the value of 0 means the cell is for the first data field, 1 for the second, and so on.
        """
        return self._data_field_index

    @DataFieldIndex.setter
    def DataFieldIndex(self, value: int) -> None:
        self._data_field_index = value

    @property
    def Result(self) -> DataResult_a47d0b1a:
        """
        more information about the result contained in the DataResult type.
        """
        return self._result

    @Result.setter
    def Result(self, value: DataResult_a47d0b1a) -> None:
        self._result = value


__all__ = ['DataPilotTableResultData']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.logging
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty, ABC
if typing.TYPE_CHECKING:
    from .x_log_handler import XLogHandler as XLogHandler_c7f80c27

class XLogger(ABC):
    """
    implemented by a component which is able to log events.
    
    This interface is roughly designed after the Java Logging API. However, there are some differences, the major ones being:
    
    **since**
    
        OOo 2.3

    See Also:
        `API XLogger <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1logging_1_1XLogger.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.logging'
    __ooo_full_ns__: str = 'com.sun.star.logging.XLogger'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.logging.XLogger'

    @abstractmethod
    def addLogHandler(self, LogHandler: XLogHandler_c7f80c27) -> None:
        """
        adds the given handler to the list of handlers.
        
        When an event is logged, the logger will create a LogRecord for this event, and pass this record to all registered handlers. Single handlers might or might not log those records at their own discretion, and depending on additional restrictions such as filters specified at handler level.
        
        Note: The log level of the given handler (XLogHandler.Level) will not be touched. In particular, it will not be set to the logger's log level. It's the responsibility of the component which knits a logger with one or more log handlers to ensure that all loggers have appropriate levels set.
        """
        ...
    @abstractmethod
    def isLoggable(self, Level: int) -> bool:
        """
        determines whether logger instance would produce any output for the given level.
        
        The method can be used to optimize performance as maybe complex parameter evaluation in the log calls can be omitted if isLoggable evaluates to false.
        """
        ...
    @abstractmethod
    def log(self, Level: int, Message: str) -> None:
        """
        logs a given message
        """
        ...
    @abstractmethod
    def logp(self, Level: int, SourceClass: str, SourceMethod: str, Message: str) -> None:
        """
        logs a given message, detailing the source class and method at which the logged event occurred.
        """
        ...
    @abstractmethod
    def removeLogHandler(self, LogHandler: XLogHandler_c7f80c27) -> None:
        """
        removes the given handler from the list of handlers.
        """
        ...
    @abstractproperty
    def Level(self) -> int:
        """
        specifies which log events are logged or ignored.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        denotes the name of the logger.
        """
        ...


__all__ = ['XLogger']


